.. quickstart_
========================
pyXMIP Quickstart Guide
========================

On this page, you can find a variety of important guides for getting started with pyXMIP!


.. card-carousel:: 1

    .. card:: pyXMIP Overview
        :link: quickstart/overview.rst

        A great first stop introduction to the core ideas behind pyXMIP.

        +++

        |beginner| |5min|



Installation + Setup
--------------------

Guides in this section are for beginning users and concern basic setup and configuration of the package to get yourself ready to roll.

.. card-carousel:: 3

    .. card:: Installing pyXMIP
        :link: quickstart/install.rst

        Instructions on installing the pyXMIP environment on your device.

        +++

        |beginner| |5min|

    .. card:: Configuration
        :link: quickstart/configuration.rst

        Learn how to change the configuration settings for your base installation.

        +++

        |beginner| |10min|

    .. card:: Adding New Databases
        :link: quickstart/new_database.rst

        Learn how to add additional databases to the built-in list already included with pyXMIP.

        +++

        |intermediate| |10min|

Critical Components
--------------------

The critical component guides are must read information for any user. We summarize the key structure of the package and
provide critical examples for all users to understand.

.. card-carousel:: 3

    .. card:: Working with tables
        :link: quickstart/tables.rst

        Instructions for working with tables in pyXMIP.

        +++

        |beginner| |5min|

    .. card:: Poisson Maps
        :link: examples/Poisson_Maps
        :link-type: doc

        Introduction to the Poisson Mapping procedures and their purpose within ``pyXMIP``.

        +++

        |intermediate| |30min|


.. |beginner| image:: https://img.shields.io/badge/Difficulty-Beginner-green
.. |intermediate| image:: https://img.shields.io/badge/Difficulty-Intermediate-blue
.. |advanced| image:: https://img.shields.io/badge/Difficulty-Advanced-black
.. |10min| image:: https://img.shields.io/badge/10min-blue
.. |5min| image:: https://img.shields.io/badge/5min-blue
.. |20min| image:: https://img.shields.io/badge/20min-blue
.. |30min| image:: https://img.shields.io/badge/30min-blue
.. |40min| image:: https://img.shields.io/badge/40min-blue
.. |60min| image:: https://img.shields.io/badge/60min-blue
.. |feature| image:: https://img.shields.io/badge/Feature-purple
.. |nyi| image::  https://img.shields.io/badge/NotYetImplemented-red
